@@ -22,28 +22,6 @@
 
 
 
-//************************************************************
-//
-//                    featureTree
-//
-//                    constructor
-//
-//************************************************************
-featureTree::featureTree()
-{
-
-}
-
-//************************************************************
-//
-//                      ~featureTree
-//
-//                        destructor
-//
-//************************************************************
-featureTree::~featureTree()
-{
-}
 
 //************************************************************
 //
@@ -514,7 +492,7 @@ booleanT featureTree::buildConstruct(estimation &Estimator, binnode* Node, int c
 
       // best
       construct bestConjunct, bestSum, bestProduct ;
-      double bestConjunctEst = -FLT_MAX, bestSumEst=-FLT_MAX, bestProductEst=-FLT_MAX ;
+      double bestConjunctEst = -DBL_MAX, bestSumEst=-DBL_MAX, bestProductEst=-DBL_MAX ;
 
       if (opt->constructionMode & cPRODUCT)
         bestProductEst = multiplicator(Estimator, bestProduct, stepMplyCache, stepMplyCacheEst) ;
@@ -535,48 +513,48 @@ booleanT featureTree::buildConstruct(estimation &Estimator, binnode* Node, int c
       if (conjIdx < stepConjCache.filled())
         Est1 = stepConjCacheEst[conjIdx] ;
       else
-        Est1 = -FLT_MAX ;
+        Est1 = -DBL_MAX ;
       if (sumIdx < stepSumCache.filled())
          Est2 = stepSumCacheEst[sumIdx] ;
       else
-        Est2 = -FLT_MAX ;
+        Est2 = -DBL_MAX ;
       if (mplyIdx < stepMplyCache.filled())
         Est3 = stepMplyCacheEst[mplyIdx] ;
       else
-        Est3 = -FLT_MAX ;
+        Est3 = -DBL_MAX ;
 
       // fill the cache
       for (i=0 ; i < opt->noCachedInNode ; i++)
       {
 
-         if (Est1 >= Est2 && Est1 >= Est3 && Est1 != -FLT_MAX)
+         if (Est1 >= Est2 && Est1 >= Est3 && Est1 != -DBL_MAX)
          {
            CachedConstructs.addEnd(stepConjCache[conjIdx]) ;
            conjIdx ++ ;
            if (conjIdx < stepConjCache.filled())
              Est1 = stepConjCacheEst[conjIdx] ;
            else
-             Est1 = -FLT_MAX ;
+             Est1 = -DBL_MAX ;
          }
          else
-            if (Est2 >= Est1 && Est2 >= Est3 && Est2 != -FLT_MAX)
+            if (Est2 >= Est1 && Est2 >= Est3 && Est2 != -DBL_MAX)
             {
               CachedConstructs.addEnd(stepSumCache[sumIdx]) ;
               sumIdx ++ ;
              if (sumIdx < stepSumCache.filled())
                Est2 = stepSumCacheEst[sumIdx] ;
              else
-               Est2 = -FLT_MAX ;
+               Est2 = -DBL_MAX ;
             }
             else
-               if (Est3 >= Est1 && Est3 >= Est2 && Est3 != -FLT_MAX)
+               if (Est3 >= Est1 && Est3 >= Est2 && Est3 != -DBL_MAX)
             {
               CachedConstructs.addEnd(stepMplyCache[mplyIdx]) ;
               mplyIdx ++ ;
               if (mplyIdx < stepMplyCache.filled())
                 Est3 = stepMplyCacheEst[mplyIdx] ;
               else
-                Est3 = -FLT_MAX ;
+                Est3 = -DBL_MAX ;
             }
             else
                break ; // none is valid
@@ -585,7 +563,7 @@ booleanT featureTree::buildConstruct(estimation &Estimator, binnode* Node, int c
       // put the best construct into the node
       if ( (opt->constructionEstimator == opt->selectionEstimator && bestEstimate >= bestConjunctEst
             && bestEstimate >= bestSumEst && bestEstimate >= bestProductEst) ||
-            (bestConjunctEst == -FLT_MAX && bestSumEst == -FLT_MAX && bestProductEst == -FLT_MAX) )
+            (bestConjunctEst == -DBL_MAX && bestSumEst == -DBL_MAX && bestProductEst == -DBL_MAX) )
       {
         // revert to single attribute
         makeSingleAttrNode(Node, Estimator, bestAttrIdx, bestAttrType) ;
